use strict;
use warnings;
package Task::Kensho::WebCrawling;
BEGIN {
  $Task::Kensho::WebCrawling::AUTHORITY = 'cpan:PERIGRIN';
}
{
  $Task::Kensho::WebCrawling::VERSION = '0.34'; # TRIAL
}
# ABSTRACT: Web Crawling

__END__

=pod

=encoding utf-8

=for :stopwords Chris Prather Buddhism EPO Kenshō nonduality amongst Organisation
installable

=head1 NAME

Task::Kensho::WebCrawling - Web Crawling

=head1 VERSION

version 0.34

=head1 SYNOPSIS

    > cpanm --verbose Task::Kensho::WebCrawling

=head1 DESCRIPTION

From L<http://en.wikipedia.org/wiki/Kensho>:

Kenshō (見性) (C. Wu) is a Japanese term for enlightenment
experiences - most commonly used within the confines of Zen
Buddhism - literally meaning "seeing one's nature"[1] or "true
self."[2] It generally "refers to the realization of nonduality of

Task::Kensho is a first cut at building a list of recommended modules
for Enlightened Perl development. CPAN is wonderful, but there are too
many wheels and you have to pick and choose amongst the various
competing technologies.

The plan is for Task::Kensho to be a rough testing ground for ideas that
go into among other things the Enlightened Perl Organisation Extended
Core (EPO-EC).

The modules that are bundled by Task::Kensho are broken down into
several categories and are still being considered. They are all taken
from various top 100 most used perl modules lists and from discussions
with various subject matter experts in the Perl Community. That said,
this bundle does I<not> follow the guidelines established for the EPO-EC
for peer review via industry advisers.

Starting in 2011, Task::Kensho split its sub-groups of modules into
individually-installable tasks. These individual tasks will always install all
their modules by default. This facilitates the ease and simplicity the
distribution aims to achieve. Each Task::Kensho sub-task is listed at the
beginning of its section in this documentation.

=head2 Web Crawling: Task::Kensho::WebCrawling

=over 4

=item L<HTTP::Lite>

Lightweight HTTP client implementation

=item L<LWP::Simple>

Simple procedural interface to LWP

=item L<LWP::UserAgent>

Full-featured Web client library for Perl

=item L<WWW::Mechanize>

Handy web browsing in a Perl object

=item L<WWW::Mechanize::TreeBuilder>

This module combines WWW::Mechanize and HTML::TreeBuilder.

=back

=head1 RELEASE SCHEDULE

Starting with release 0.18 Task::Kensho was moved to a monthly release
cycle. This will facilitate a consistent schedule for upstream vendors
to track the changes in Task::Kensho.

=head1 BUGS AND LIMITATIONS

This list is by no means comprehensive of the "Good" Modules on CPAN.
Nor is this necessarily the correct path for all developers. Each of
these modules has a perfectly acceptable replacement that may work
better for you. This is however a path to good perl practice, and a
starting place on the road to Enlightened Perl programming.

Please report any bugs or feature requests to
C<bug-task-kensho@rt.cpan.org>, or through the web interface at
L<http://rt.cpan.org>.

=head1 SEE ALSO

L<http://www.enlightenedperl.org/>,
L<Perl::Dist::Strawberry|Perl::Dist::Strawberry>

=head1 AUTHOR

Chris Prather <chris@prather.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2008 by Chris Prather.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
